pub struct AudienceId {
pub canonical_network_id: CanonicalId,
pub fleet_id: CanonicalId,
}Expand description
Exact network-qualified audience, with existing protocol field labels. The host owns the meaning and trusted source of both identifiers; this type contains no fleet topology, membership, derivation or installation policy.
Fields
canonical_network_id: CanonicalIdfleet_id: CanonicalIdTrait Implementations
Sourceimpl CandidType for AudienceId
impl CandidType for AudienceId
Sourceimpl Clone for AudienceId
impl Clone for AudienceId
impl Copy for AudienceId
Sourceimpl Debug for AudienceId
impl Debug for AudienceId
Sourceimpl<'de> Deserialize<'de> for AudienceId
impl<'de> Deserialize<'de> for AudienceId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AudienceId
Sourceimpl Hash for AudienceId
impl Hash for AudienceId
Sourceimpl Ord for AudienceId
impl Ord for AudienceId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for AudienceId
impl PartialEq for AudienceId
Sourceimpl PartialOrd for AudienceId
impl PartialOrd for AudienceId
Sourceimpl Serialize for AudienceId
impl Serialize for AudienceId
impl StructuralPartialEq for AudienceId